@@ -1,12 +1,12 @@
 import os
 
 __author__ = 'Romain Tavenard romain.tavenard[at]univ-rennes2.fr'
-__version__ = "0.1.29"
-__bibtex__ = """@misc{tslearn,
+__version__ = "0.2.2"
+__bibtex__ = r"""@misc{tslearn,
  title={tslearn: A machine learning toolkit dedicated to time-series data},
- author={Tavenard, Romain},
+ author={Tavenard, Romain and Faouzi, Johann and Vandewiele, Gilles},
  year={2017},
- note={\\url{https://github.com/rtavenar/tslearn}}
+ note={\url{https://github.com/rtavenar/tslearn}}
 }"""
 
 
